@@ -1,5 +1,5 @@
 import aiohttp
-import json
+import json as JSON
 from .exceptions import InvalidPlayerNameError
 
 MOJANG_API = "https://api.mojang.com"
@@ -8,8 +8,8 @@ async def get_uuid(name):
 	async with aiohttp.ClientSession() as client:
 		async with client.get(f"{MOJANG_API}/users/profiles/minecraft/{name}") as response:
 			try:
-				json = response.json()
+				json = await response.json()
 				return json["id"]
-			except json.decoder.JSONDecodeError:
+			except JSON.decoder.JSONDecodeError:
 				raise InvalidPlayerNameError
 		
\ No newline at end of file
